# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from nemollm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from nemollm.model.classification import Classification
from nemollm.model.completion_request_body import CompletionRequestBody
from nemollm.model.completion_response_body import CompletionResponseBody
from nemollm.model.create_customizations_request_body import CreateCustomizationsRequestBody
from nemollm.model.create_customizations_request_body_additional_hyperparameters import (
    CreateCustomizationsRequestBodyAdditionalHyperparameters,
)
from nemollm.model.customization import Customization
from nemollm.model.customization_status import CustomizationStatus
from nemollm.model.customizations_list_response_body import CustomizationsListResponseBody
from nemollm.model.file import File
from nemollm.model.file_format import FileFormat
from nemollm.model.list_meta import ListMeta
from nemollm.model.model import Model
from nemollm.model.models_list_response import ModelsListResponse
from nemollm.model.p_tuning_hyperparms import PTuningHyperparms
from nemollm.model.pagination_links import PaginationLinks



"""
    NVIDIA NeMo LLM service

    # Introduction NeMo LLM Service offers state-of-the-art LLMs that were pre-trained on internet-scale text corpora. </br> With NeMo LLM Service API users can invoke the services from within their application code. </br> These models can be flexibly adapted to solve almost any language processing task for your use cases. You can conveniently and quickly try them out, and via an API that you can easily integrate into your applications. </br> Further, the NeMo LLM Service also offers customization capabilities, where the models can be effectively adapted to new tasks, using your own uploaded data.  ### Models:  The NeMo LLM Service is powered by a set of large language models of varying sizes and capabilities. Generally, larger models extend the capabilities of what smaller models can do with text. - Large models, such as the 530B, are excellent for complex tasks that require a deep understanding of human languages and all their nuances, such as text summarization, creative writing, or chatbot applications. - Medium models, such as the 20B, are faster than the large models. They are sufficiently good for many tasks such as writing emails and factual question answering. - Small models, such as the 5B, are the fastest and can perform many simple language tasks, such as text classification and spelling correction. </br></br> Each model can be used for \"Completion\" or text generation with One/Few-Shot Learning as well as \"Customization\" with your custom dataset. </br></br> ### The NeMo LLM Service API  comprises the following features:   - Text Completion. With one of the available and pre-trained model the LLM service responds to an input prompt by generating an extension to the provided intut text, that is, a completion. This technique can be used for solving multiple NLP tasks using Zero/Few-shot learning techniques.   - Model Customization. With which you can finetune an existing model on your own custom data in the form of prompt+completion pairs. This enhances the model’s ability to adapt to your use cases by ingesting hundreds to thousands of domain-specific examples.   Please **[submit NVBug](https://nvbugswb.nvidia.com/NvBugs5/SWBug.aspx?bugid=3682160&cmtNo=)** (by cloning and submitting) if discovered any issues.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from multiprocessing.pool import ApplyResult
from typing import Any, Dict, List, Optional, Tuple, Union

from nemollm.api.default_api import DefaultApi
from nemollm.api_client import ApiClient
from nemollm.configuration import Configuration
from nemollm.model.completion_request_body import CompletionRequestBody
from nemollm.model.completion_response_body import CompletionResponseBody
from nemollm.model.create_customizations_request_body import CreateCustomizationsRequestBody
from nemollm.model.create_customizations_request_body_additional_hyperparameters import (
    CreateCustomizationsRequestBodyAdditionalHyperparameters,
)
from nemollm.model.customization import Customization
from nemollm.model.customizations_list_response_body import CustomizationsListResponseBody
from nemollm.model.file import File
from nemollm.model.file_format import FileFormat
from nemollm.model.models_list_response import ModelsListResponse
from nemollm.model.p_tuning_hyperparms import PTuningHyperparms


class Connection:
    """
    A wrapper which contains instances of ``nemollm.api_client.ApiClient`` and
    ``nemollm.api.default_api.DefaultApi`` and routes create_customization(), delete_customization(), delete_file(), fetch_model_file_for_customization(), generate_completion(), generate_customization_completion(), get_customization(), get_file(), list_customizations(), list_customizations_for_model(), list_files(), list_models(), upload_file(),  to
    corresponding methods of ``nemollm.api.default_api.DefaultApi``.
    """

    def __init__(
        self,
        # `nemollm.configuration.Configuration.__init__()` parameters
        host: Optional[str] = "",
        api_key: Optional[Dict[str, str]] = None,
        api_key_prefix: Optional[Dict[str, str]] = None,
        access_token: str = None,
        username: Optional[str] = None,
        password: Optional[str] = None,
        discard_unknown_keys: bool = False,
        disabled_client_side_validations: str = "",
        server_index: Optional[int] = None,
        server_variables: Dict[str, Any] = None,
        server_operation_index: Optional[Dict[str, int]] = None,
        server_operation_variables: Optional[Dict[str, Dict[str, str]]] = None,
        ssl_ca_cert: Optional[str] = None,
        # `nemollm.api_client.ApiClient.__init__()` parameters except for `configuration`
        header_name: Optional[str] = None,
        header_value: Optional[str] = None,
        cookie=None,
        pool_threads: int = 1,
        **kwargs
    ):

        """
        This constructor accepts parameters of `nemollm.configuration.Configuration.__init__()` and
        `nemollm.api_client.ApiClient.__init__()`.

        Ref: https://openapi-generator.tech
        Do not edit the class manually.

        :param host: Base url, defaults to ``"https://api.bignlp.nvidia.com/v1"``
        :param api_key: Dict to store API key(s).
            Each entry in the dict specifies an API key.
            The dict key is the name of the security scheme in the OAS specification.
            The dict value is the API key secret.
        :param api_key_prefix: Dict to store API prefix (e.g. Bearer)
            The dict key is the name of the security scheme in the OAS specification.
            The dict value is an API key prefix when generating the auth data.
        :param username: Username for HTTP basic authentication
        :param password: Password for HTTP basic authentication
        :param discard_unknown_keys: Boolean value indicating whether to discard
            unknown properties. A server may send a response that includes additional
            properties that are not known by the client in the following scenarios:
            1. The OpenAPI document is incomplete, i.e. it does not match the server
             implementation.
            2. The client was generated using an older version of the OpenAPI document
             and the server has been upgraded since then.
            If a schema in the OpenAPI document defines the additionalProperties attribute,
            then all undeclared properties received by the server are injected into the
            additional properties map. In that case, there are undeclared properties, and
            nothing to discard.
        :param disabled_client_side_validations (string): Comma-separated list of
            JSON schema validation keywords to disable JSON schema structural validation
            rules. The following keywords may be specified: multipleOf, maximum,
            exclusiveMaximum, minimum, exclusiveMinimum, maxLength, minLength, pattern,
            maxItems, minItems.
            By default, the validation is performed for data generated locally by the client
            and data received from the server, independent of any validation performed by
            the server side. If the input data does not satisfy the JSON schema validation
            rules specified in the OpenAPI document, an exception is raised.
            If disabled_client_side_validations is set, structural validation is
            disabled. This can be useful to troubleshoot data validation problem, such as
            when the OpenAPI document validation rules do not match the actual API data
            received by the server.
        :param server_index: Index to servers configuration.
        :param server_variables: Mapping with string values to replace variables in
            templated server configuration. The validation of enums is performed for
            variables with defined enum values before.
        :param server_operation_index: Mapping from operation ID to an index to server
            configuration.
        :param server_operation_variables: Mapping from operation ID to a mapping with
            string values to replace variables in templated server configuration.
            The validation of enums is performed for variables with defined enum values before.
        :param ssl_ca_cert: str - the path to a file of concatenated CA certificates
            in PEM format
        :param header_name: a header to pass when making calls to the API.
        :param header_value: a header value to pass when making calls to
            the API.
        :param cookie: a cookie to include in the header when making calls
            to the API
        :param pool_threads: The number of threads to use for async requests
            to the API. More threads means more concurrent API requests.
        """
        configuration = Configuration(
            host=host,
            api_key=api_key,
            api_key_prefix=api_key_prefix,
            access_token=access_token,
            username=username,
            password=password,
            discard_unknown_keys=discard_unknown_keys,
            disabled_client_side_validations=disabled_client_side_validations,
            server_index=server_index,
            server_variables=server_variables,
            server_operation_index=server_operation_index,
            server_operation_variables=server_operation_variables,
            ssl_ca_cert=ssl_ca_cert,
        )
        self.api_client = ApiClient(
            configuration, header_name=header_name, header_value=header_value, cookie=cookie, pool_threads=pool_threads
        )
        self.api_instance = DefaultApi(self.api_client)

    def create_customization(
        self,
        model_id="gpt530b",
        name="",
        description="",
        prompt_template="",
        training_dataset_file_id="",
        validation_dataset_file_id="",
        batch_size=64,
        epochs=25,
        learning_rate=0.00010,
        additional_hyperparameters="",
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        model_id = model_id
        create_customizations_request_body = CreateCustomizationsRequestBody(
            name=name,
            description=description,
            prompt_template=prompt_template,
            training_dataset_file_id=training_dataset_file_id,
            validation_dataset_file_id=validation_dataset_file_id,
            batch_size=batch_size,
            epochs=epochs,
            learning_rate=learning_rate,
            additional_hyperparameters=additional_hyperparameters,
        )

        # Create model customization
        return self.api_instance.create_customization(
            model_id,
            create_customizations_request_body=create_customizations_request_body,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def delete_customization(
        self,
        model_id="gpt530b",
        customization_id="QnA",
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        model_id = model_id
        customization_id = customization_id

        # Delete the custom model
        return self.api_instance.delete_customization(
            model_id,
            customization_id,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def delete_file(
        self,
        file_id="file_id_example",
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        file_id = file_id

        # Delete file
        return self.api_instance.delete_file(
            file_id,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def fetch_model_file_for_customization(
        self,
        model_id="gpt530b",
        customization_id="QnA",
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        model_id = model_id
        customization_id = customization_id

        # Fetch NEMO file with trained prompt tokens
        return self.api_instance.fetch_model_file_for_customization(
            model_id,
            customization_id,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def generate_completion(
        self,
        model_id="gpt530b",
        prompt="",
        tokens_to_generate=24,
        logprobs=False,
        temperature=1.0,
        top_p=1.0,
        top_k=1,
        stop=[],
        random_seed=0,
        repetition_penalty=1.0,
        beam_search_diversity_rate=1.0,
        beam_width=1,
        length_penalty=1.0,
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        model_id = model_id
        completion_request_body = CompletionRequestBody(
            prompt=prompt,
            tokens_to_generate=tokens_to_generate,
            logprobs=logprobs,
            temperature=temperature,
            top_p=top_p,
            top_k=top_k,
            stop=stop,
            random_seed=random_seed,
            repetition_penalty=repetition_penalty,
            beam_search_diversity_rate=beam_search_diversity_rate,
            beam_width=beam_width,
            length_penalty=length_penalty,
        )

        # Create text completion
        return self.api_instance.generate_completion(
            model_id,
            completion_request_body=completion_request_body,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def generate_customization_completion(
        self,
        model_id="gpt530b",
        customization_id="QnA",
        prompt="",
        tokens_to_generate=24,
        logprobs=False,
        temperature=1.0,
        top_p=1.0,
        top_k=1,
        stop=[],
        random_seed=0,
        repetition_penalty=1.0,
        beam_search_diversity_rate=1.0,
        beam_width=1,
        length_penalty=1.0,
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        model_id = model_id
        customization_id = customization_id
        completion_request_body = CompletionRequestBody(
            prompt=prompt,
            tokens_to_generate=tokens_to_generate,
            logprobs=logprobs,
            temperature=temperature,
            top_p=top_p,
            top_k=top_k,
            stop=stop,
            random_seed=random_seed,
            repetition_penalty=repetition_penalty,
            beam_search_diversity_rate=beam_search_diversity_rate,
            beam_width=beam_width,
            length_penalty=length_penalty,
        )

        # Create text completion with customized model
        return self.api_instance.generate_customization_completion(
            model_id,
            customization_id,
            completion_request_body=completion_request_body,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def get_customization(
        self,
        model_id="gpt530b",
        customization_id="QnA",
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        model_id = model_id
        customization_id = customization_id

        # Get info about model customization
        return self.api_instance.get_customization(
            model_id,
            customization_id,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def get_file(
        self,
        file_id="file_id_example",
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        file_id = file_id

        # Get file
        return self.api_instance.get_file(
            file_id,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def list_customizations(
        self,
        shared="private",
        page=1,
        page_size=15,
        sort_by="created_at",
        order="desc",
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        shared = shared
        page = page
        page_size = page_size
        sort_by = sort_by
        order = order

    def list_customizations_for_model(
        self,
        model_id="gpt530b",
        shared="private",
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        model_id = model_id
        shared = shared

        # List models customizations
        return self.api_instance.list_customizations_for_model(
            model_id,
            shared=shared,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )

    def list_files(
        self,
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        return self.api_instance.list_files()

    def list_models(
        self,
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        return self.api_instance.list_models()

    def upload_file(
        self,
        file='/path/to/file',
        format=FileFormat("jsonl"),
        async_req: bool = False,
        _return_http_data_only: bool = True,
        _preload_content: bool = True,
        _request_timeout: Optional[Union[int, float, Tuple[float, float]]] = None,
        _check_input_type: bool = True,
        _check_return_type: bool = True,
        _content_type: Optional[str] = None,
        _host_index: Optional[int] = None,
        _request_auths: Optional[List[Dict[str, str]]] = None,
        **kwargs
    ):
        file = open(file, 'rb')
        format = format

        # Upload file
        return self.api_instance.upload_file(
            file,
            format,
            async_req=async_req,
            _return_http_data_only=_return_http_data_only,
            _preload_content=_preload_content,
            _request_timeout=_request_timeout,
            _check_input_type=_check_input_type,
            _check_return_type=_check_return_type,
            _content_type=_content_type,
            _host_index=_host_index,
            _request_auths=_request_auths,
            **kwargs
        )



"""
    NVIDIA NeMo LLM service

    # Introduction NeMo LLM Service offers state-of-the-art LLMs that were pre-trained on internet-scale text corpora. </br> With NeMo LLM Service API users can invoke the services from within their application code. </br> These models can be flexibly adapted to solve almost any language processing task for your use cases. You can conveniently and quickly try them out, and via an API that you can easily integrate into your applications. </br> Further, the NeMo LLM Service also offers customization capabilities, where the models can be effectively adapted to new tasks, using your own uploaded data.  ### Models:  The NeMo LLM Service is powered by a set of large language models of varying sizes and capabilities. Generally, larger models extend the capabilities of what smaller models can do with text. - Large models, such as the 530B, are excellent for complex tasks that require a deep understanding of human languages and all their nuances, such as text summarization, creative writing, or chatbot applications. - Medium models, such as the 20B, are faster than the large models. They are sufficiently good for many tasks such as writing emails and factual question answering. - Small models, such as the 5B, are the fastest and can perform many simple language tasks, such as text classification and spelling correction. </br></br> Each model can be used for \"Completion\" or text generation with One/Few-Shot Learning as well as \"Customization\" with your custom dataset. </br></br> ### The NeMo LLM Service API  comprises the following features:   - Text Completion. With one of the available and pre-trained model the LLM service responds to an input prompt by generating an extension to the provided intut text, that is, a completion. This technique can be used for solving multiple NLP tasks using Zero/Few-shot learning techniques.   - Model Customization. With which you can finetune an existing model on your own custom data in the form of prompt+completion pairs. This enhances the model’s ability to adapt to your use cases by ingesting hundreds to thousands of domain-specific examples.   Please **[submit NVBug](https://nvbugswb.nvidia.com/NvBugs5/SWBug.aspx?bugid=3682160&cmtNo=)** (by cloning and submitting) if discovered any issues.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from nemollm.exceptions import ApiAttributeError
from nemollm.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    OpenApiModel,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)


class ListMeta(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {}

    validations = {}

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        return (
            bool,
            date,
            datetime,
            dict,
            float,
            int,
            list,
            str,
            none_type,
        )  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'page': (int,),  # noqa: E501
            'page_size': (int,),  # noqa: E501
            'total_pages': (int,),  # noqa: E501
            'total_results': (int,),  # noqa: E501
            'sort_by': (str,),  # noqa: E501
            'order': (str,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None

    attribute_map = {
        'page': 'page',  # noqa: E501
        'page_size': 'page_size',  # noqa: E501
        'total_pages': 'total_pages',  # noqa: E501
        'total_results': 'total_results',  # noqa: E501
        'sort_by': 'sort_by',  # noqa: E501
        'order': 'order',  # noqa: E501
    }

    read_only_vars = {}

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """ListMeta - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            page (int): The current page number. [optional]  # noqa: E501
            page_size (int): Number of results per page. [optional]  # noqa: E501
            total_pages (int): Total number of pages for the query. [optional]  # noqa: E501
            total_results (int): Total number of results for the query. [optional]  # noqa: E501
            sort_by (str): The sorting field for the query. [optional]  # noqa: E501
            order (str): The ordering of results for the query. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments."
                        % (args, self.__class__.__name__,),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if (
                var_name not in self.attribute_map
                and self._configuration is not None
                and self._configuration.discard_unknown_keys
                and self.additional_properties_type is None
            ):
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set(
        [
            '_data_store',
            '_check_type',
            '_spec_property_naming',
            '_path_to_item',
            '_configuration',
            '_visited_composed_classes',
        ]
    )

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """ListMeta - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            page (int): The current page number. [optional]  # noqa: E501
            page_size (int): Number of results per page. [optional]  # noqa: E501
            total_pages (int): Total number of pages for the query. [optional]  # noqa: E501
            total_results (int): Total number of results for the query. [optional]  # noqa: E501
            sort_by (str): The sorting field for the query. [optional]  # noqa: E501
            order (str): The ordering of results for the query. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments."
                        % (args, self.__class__.__name__,),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if (
                var_name not in self.attribute_map
                and self._configuration is not None
                and self._configuration.discard_unknown_keys
                and self.additional_properties_type is None
            ):
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(
                    f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                    f"class with read only attributes."
                )



"""
    NVIDIA NeMo LLM service

    # Introduction NeMo LLM Service offers state-of-the-art LLMs that were pre-trained on internet-scale text corpora. </br> With NeMo LLM Service API users can invoke the services from within their application code. </br> These models can be flexibly adapted to solve almost any language processing task for your use cases. You can conveniently and quickly try them out, and via an API that you can easily integrate into your applications. </br> Further, the NeMo LLM Service also offers customization capabilities, where the models can be effectively adapted to new tasks, using your own uploaded data.  ### Models:  The NeMo LLM Service is powered by a set of large language models of varying sizes and capabilities. Generally, larger models extend the capabilities of what smaller models can do with text. - Large models, such as the 530B, are excellent for complex tasks that require a deep understanding of human languages and all their nuances, such as text summarization, creative writing, or chatbot applications. - Medium models, such as the 20B, are faster than the large models. They are sufficiently good for many tasks such as writing emails and factual question answering. - Small models, such as the 5B, are the fastest and can perform many simple language tasks, such as text classification and spelling correction. </br></br> Each model can be used for \"Completion\" or text generation with One/Few-Shot Learning as well as \"Customization\" with your custom dataset. </br></br> ### The NeMo LLM Service API  comprises the following features:   - Text Completion. With one of the available and pre-trained model the LLM service responds to an input prompt by generating an extension to the provided intut text, that is, a completion. This technique can be used for solving multiple NLP tasks using Zero/Few-shot learning techniques.   - Model Customization. With which you can finetune an existing model on your own custom data in the form of prompt+completion pairs. This enhances the model’s ability to adapt to your use cases by ingesting hundreds to thousands of domain-specific examples.   Please **[submit NVBug](https://nvbugswb.nvidia.com/NvBugs5/SWBug.aspx?bugid=3682160&cmtNo=)** (by cloning and submitting) if discovered any issues.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from nemollm.api_client import ApiClient
from nemollm.api_client import Endpoint as _Endpoint
from nemollm.model.completion_request_body import CompletionRequestBody
from nemollm.model.completion_response_body import CompletionResponseBody
from nemollm.model.create_customizations_request_body import CreateCustomizationsRequestBody
from nemollm.model.customization import Customization
from nemollm.model.customizations_list_response_body import CustomizationsListResponseBody
from nemollm.model.file import File
from nemollm.model.file_format import FileFormat
from nemollm.model.models_list_response import ModelsListResponse
from nemollm.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types,
)


class DefaultApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_customization_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/models/{model_id}/customizations',
                'operation_id': 'create_customization',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': ['model_id', 'create_customizations_request_body',],
                'required': ['model_id',],
                'nullable': [],
                'enum': [],
                'validation': [],
            },
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {
                    'model_id': (str,),
                    'create_customizations_request_body': (CreateCustomizationsRequestBody,),
                },
                'attribute_map': {'model_id': 'model_id',},
                'location_map': {'model_id': 'path', 'create_customizations_request_body': 'body',},
                'collection_format_map': {},
            },
            headers_map={'accept': [], 'content_type': ['application/json']},
            api_client=api_client,
        )
        self.delete_customization_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/models/{model_id}/customizations/{customization_id}',
                'operation_id': 'delete_customization',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': ['model_id', 'customization_id',],
                'required': ['model_id', 'customization_id',],
                'nullable': [],
                'enum': [],
                'validation': [],
            },
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {'model_id': (str,), 'customization_id': (str,),},
                'attribute_map': {'model_id': 'model_id', 'customization_id': 'customization_id',},
                'location_map': {'model_id': 'path', 'customization_id': 'path',},
                'collection_format_map': {},
            },
            headers_map={'accept': [], 'content_type': [],},
            api_client=api_client,
        )
        self.delete_file_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/files/{file_id}',
                'operation_id': 'delete_file',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={'all': ['file_id',], 'required': ['file_id',], 'nullable': [], 'enum': [], 'validation': []},
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {'file_id': (str,),},
                'attribute_map': {'file_id': 'file_id',},
                'location_map': {'file_id': 'path',},
                'collection_format_map': {},
            },
            headers_map={'accept': [], 'content_type': [],},
            api_client=api_client,
        )
        self.fetch_model_file_for_customization_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/models/{model_id}/customizations/{customization_id}/fetch',
                'operation_id': 'fetch_model_file_for_customization',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': ['model_id', 'customization_id',],
                'required': ['model_id', 'customization_id',],
                'nullable': [],
                'enum': [],
                'validation': [],
            },
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {'model_id': (str,), 'customization_id': (str,),},
                'attribute_map': {'model_id': 'model_id', 'customization_id': 'customization_id',},
                'location_map': {'model_id': 'path', 'customization_id': 'path',},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/octet-stream'], 'content_type': [],},
            api_client=api_client,
        )
        self.generate_completion_endpoint = _Endpoint(
            settings={
                'response_type': (CompletionResponseBody,),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/models/{model_id}/completions',
                'operation_id': 'generate_completion',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': ['model_id', 'completion_request_body',],
                'required': ['model_id',],
                'nullable': [],
                'enum': [],
                'validation': [],
            },
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {'model_id': (str,), 'completion_request_body': (CompletionRequestBody,),},
                'attribute_map': {'model_id': 'model_id',},
                'location_map': {'model_id': 'path', 'completion_request_body': 'body',},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': ['application/json']},
            api_client=api_client,
        )
        self.generate_customization_completion_endpoint = _Endpoint(
            settings={
                'response_type': (CompletionResponseBody,),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/models/{model_id}/customizations/{customization_id}/completions',
                'operation_id': 'generate_customization_completion',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': ['model_id', 'customization_id', 'completion_request_body',],
                'required': ['model_id', 'customization_id',],
                'nullable': [],
                'enum': [],
                'validation': [],
            },
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {
                    'model_id': (str,),
                    'customization_id': (str,),
                    'completion_request_body': (CompletionRequestBody,),
                },
                'attribute_map': {'model_id': 'model_id', 'customization_id': 'customization_id',},
                'location_map': {'model_id': 'path', 'customization_id': 'path', 'completion_request_body': 'body',},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': ['application/json']},
            api_client=api_client,
        )
        self.get_customization_endpoint = _Endpoint(
            settings={
                'response_type': (Customization,),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/models/{model_id}/customizations/{customization_id}',
                'operation_id': 'get_customization',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': ['model_id', 'customization_id',],
                'required': ['model_id', 'customization_id',],
                'nullable': [],
                'enum': [],
                'validation': [],
            },
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {'model_id': (str,), 'customization_id': (str,),},
                'attribute_map': {'model_id': 'model_id', 'customization_id': 'customization_id',},
                'location_map': {'model_id': 'path', 'customization_id': 'path',},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': [],},
            api_client=api_client,
        )
        self.get_file_endpoint = _Endpoint(
            settings={
                'response_type': (File,),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/files/{file_id}',
                'operation_id': 'get_file',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={'all': ['file_id',], 'required': ['file_id',], 'nullable': [], 'enum': [], 'validation': []},
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {'file_id': (str,),},
                'attribute_map': {'file_id': 'file_id',},
                'location_map': {'file_id': 'path',},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': [],},
            api_client=api_client,
        )
        self.list_customizations_endpoint = _Endpoint(
            settings={
                'response_type': (CustomizationsListResponseBody,),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/customizations',
                'operation_id': 'list_customizations',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': ['shared', 'page', 'page_size', 'sort_by', 'order',],
                'required': [],
                'nullable': [],
                'enum': ['shared', 'sort_by', 'order',],
                'validation': ['page', 'page_size',],
            },
            root_map={
                'validations': {
                    ('page',): {'inclusive_minimum': 1,},
                    ('page_size',): {'inclusive_maximum': 100, 'inclusive_minimum': 1,},
                },
                'allowed_values': {
                    ('shared',): {"PRIVATE": "private", "PUBLIC": "public"},
                    ('sort_by',): {"CREATED_AT": "created_at", "UPDATED_AT": "updated_at"},
                    ('order',): {"ASC": "asc", "DESC": "desc"},
                },
                'openapi_types': {
                    'shared': (str,),
                    'page': (int,),
                    'page_size': (int,),
                    'sort_by': (str,),
                    'order': (str,),
                },
                'attribute_map': {
                    'shared': 'shared',
                    'page': 'page',
                    'page_size': 'page_size',
                    'sort_by': 'sort_by',
                    'order': 'order',
                },
                'location_map': {
                    'shared': 'query',
                    'page': 'query',
                    'page_size': 'query',
                    'sort_by': 'query',
                    'order': 'query',
                },
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': [],},
            api_client=api_client,
        )
        self.list_customizations_for_model_endpoint = _Endpoint(
            settings={
                'response_type': ([Customization],),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/models/{model_id}/customizations',
                'operation_id': 'list_customizations_for_model',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': ['model_id', 'shared',],
                'required': ['model_id',],
                'nullable': [],
                'enum': ['shared',],
                'validation': [],
            },
            root_map={
                'validations': {},
                'allowed_values': {('shared',): {"PRIVATE": "private", "PUBLIC": "public"},},
                'openapi_types': {'model_id': (str,), 'shared': (str,),},
                'attribute_map': {'model_id': 'model_id', 'shared': 'shared',},
                'location_map': {'model_id': 'path', 'shared': 'query',},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': [],},
            api_client=api_client,
        )
        self.list_files_endpoint = _Endpoint(
            settings={
                'response_type': ([File],),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/files',
                'operation_id': 'list_files',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={'all': [], 'required': [], 'nullable': [], 'enum': [], 'validation': []},
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {},
                'attribute_map': {},
                'location_map': {},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': [],},
            api_client=api_client,
        )
        self.list_models_endpoint = _Endpoint(
            settings={
                'response_type': (ModelsListResponse,),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/models',
                'operation_id': 'list_models',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={'all': [], 'required': [], 'nullable': [], 'enum': [], 'validation': []},
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {},
                'attribute_map': {},
                'location_map': {},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': [],},
            api_client=api_client,
        )
        self.upload_file_endpoint = _Endpoint(
            settings={
                'response_type': (File,),
                'auth': ['ApiKeyAuth'],
                'endpoint_path': '/files',
                'operation_id': 'upload_file',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': ['file', 'format',],
                'required': ['file', 'format',],
                'nullable': [],
                'enum': [],
                'validation': ['file',],
            },
            root_map={
                'validations': {},
                'allowed_values': {},
                'openapi_types': {'file': (file_type,), 'format': (FileFormat,),},
                'attribute_map': {'file': 'file', 'format': 'format',},
                'location_map': {'file': 'form', 'format': 'form',},
                'collection_format_map': {},
            },
            headers_map={'accept': ['application/json'], 'content_type': ['multipart/form-data']},
            api_client=api_client,
        )

    def create_customization(self, model_id, **kwargs):
        """Create model customization  # noqa: E501

        This API endpoint allows the creation of a new customized model using an available uploaded dataset  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_customization(model_id, async_req=True)
        >>> result = thread.get()

        Args:
            model_id (str): The Model ID. Completion requests can be sent to different backend engines serving different models. 

        Keyword Args:
            create_customizations_request_body (CreateCustomizationsRequestBody): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['model_id'] = model_id
        return self.create_customization_endpoint.call_with_http_info(**kwargs)

    def delete_customization(self, model_id, customization_id, **kwargs):
        """Delete the custom model  # noqa: E501

        Delete the customization of the model created by user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_customization(model_id, customization_id, async_req=True)
        >>> result = thread.get()

        Args:
            model_id (str): The Model ID. Completion requests can be sent to different backend engines serving different models. 
            customization_id (str): The customization ID 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['model_id'] = model_id
        kwargs['customization_id'] = customization_id
        return self.delete_customization_endpoint.call_with_http_info(**kwargs)

    def delete_file(self, file_id, **kwargs):
        """Delete file  # noqa: E501

        Delete file (dataset).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_file(file_id, async_req=True)
        >>> result = thread.get()

        Args:
            file_id (str): File ID

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['file_id'] = file_id
        return self.delete_file_endpoint.call_with_http_info(**kwargs)

    def fetch_model_file_for_customization(self, model_id, customization_id, **kwargs):
        """Fetch NEMO file with trained prompt tokens  # noqa: E501

        Fetch NEMO file with trained prompt tokens.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.fetch_model_file_for_customization(model_id, customization_id, async_req=True)
        >>> result = thread.get()

        Args:
            model_id (str): The Model ID. Completion requests can be sent to different backend engines serving different models. 
            customization_id (str): The customization ID 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['model_id'] = model_id
        kwargs['customization_id'] = customization_id
        return self.fetch_model_file_for_customization_endpoint.call_with_http_info(**kwargs)

    def generate_completion(self, model_id, **kwargs):
        """Create text completion  # noqa: E501

        The text completion function is the center of the NeMo LLM service, generating a text completion given the prompt and hyperparameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_completion(model_id, async_req=True)
        >>> result = thread.get()

        Args:
            model_id (str): The Model ID. Completion requests can be sent to different backend engines serving different models. 

        Keyword Args:
            completion_request_body (CompletionRequestBody): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CompletionResponseBody
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['model_id'] = model_id
        return self.generate_completion_endpoint.call_with_http_info(**kwargs)

    def generate_customization_completion(self, model_id, customization_id, **kwargs):
        """Create text completion with customized model  # noqa: E501

        Creates a text completion with one of the models customized by the user given a prompt and hyperparameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_customization_completion(model_id, customization_id, async_req=True)
        >>> result = thread.get()

        Args:
            model_id (str): The Model ID. Completion requests can be sent to different backend engines serving different models. 
            customization_id (str): The customization ID 

        Keyword Args:
            completion_request_body (CompletionRequestBody): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CompletionResponseBody
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['model_id'] = model_id
        kwargs['customization_id'] = customization_id
        return self.generate_customization_completion_endpoint.call_with_http_info(**kwargs)

    def get_customization(self, model_id, customization_id, **kwargs):
        """Get info about model customization  # noqa: E501

        Get information and status about the custom model. Can be used for checking the status of the customization process.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_customization(model_id, customization_id, async_req=True)
        >>> result = thread.get()

        Args:
            model_id (str): The Model ID. Completion requests can be sent to different backend engines serving different models. 
            customization_id (str): The customization ID 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Customization
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['model_id'] = model_id
        kwargs['customization_id'] = customization_id
        return self.get_customization_endpoint.call_with_http_info(**kwargs)

    def get_file(self, file_id, **kwargs):
        """Get file  # noqa: E501

        Download file (dataset) in jsonl format that can be used for model customization or validation of the customized model.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_file(file_id, async_req=True)
        >>> result = thread.get()

        Args:
            file_id (str): File ID

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            File
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['file_id'] = file_id
        return self.get_file_endpoint.call_with_http_info(**kwargs)

    def list_customizations(self, **kwargs):
        """List customizations for the model  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_customizations(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            shared (str): Public and private customizations. [optional]
            page (int): Page number. [optional] if omitted the server will use the default value of 1
            page_size (int): Number of results per page. [optional] if omitted the server will use the default value of 15
            sort_by (str): Sort results by the specified field. [optional] if omitted the server will use the default value of "created_at"
            order (str): Order the results. [optional] if omitted the server will use the default value of "desc"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CustomizationsListResponseBody
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_customizations_endpoint.call_with_http_info(**kwargs)

    def list_customizations_for_model(self, model_id, **kwargs):
        """List models customizations  # noqa: E501

        This API endpoint returns the list of models customized by user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_customizations_for_model(model_id, async_req=True)
        >>> result = thread.get()

        Args:
            model_id (str): The Model ID. Completion requests can be sent to different backend engines serving different models. 

        Keyword Args:
            shared (str): Public and private customizations. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [Customization]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['model_id'] = model_id
        return self.list_customizations_for_model_endpoint.call_with_http_info(**kwargs)

    def list_files(self, **kwargs):
        """List all files  # noqa: E501

        Provides a list of all files uploaded by the user. These files are datasets in jsonl format that can be used for model customization or validation of the customized model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_files(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [File]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_files_endpoint.call_with_http_info(**kwargs)

    def list_models(self, **kwargs):
        """List models  # noqa: E501

        An API function is provides to obtain a list of all models available for text completion as well as for customization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_models(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ModelsListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_models_endpoint.call_with_http_info(**kwargs)

    def upload_file(self, file, format, **kwargs):
        """Upload file  # noqa: E501

        Upload file in jsonl format that can be used for model customization or validation of the customized model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_file(file, format, async_req=True)
        >>> result = thread.get()

        Args:
            file (file_type):
            format (FileFormat):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            File
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get('async_req', False)
        kwargs['_return_http_data_only'] = kwargs.get('_return_http_data_only', True)
        kwargs['_preload_content'] = kwargs.get('_preload_content', True)
        kwargs['_request_timeout'] = kwargs.get('_request_timeout', None)
        kwargs['_check_input_type'] = kwargs.get('_check_input_type', True)
        kwargs['_check_return_type'] = kwargs.get('_check_return_type', True)
        kwargs['_spec_property_naming'] = kwargs.get('_spec_property_naming', False)
        kwargs['_content_type'] = kwargs.get('_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['file'] = file
        kwargs['format'] = format
        return self.upload_file_endpoint.call_with_http_info(**kwargs)



"""
    NVIDIA NeMo LLM service

    # Introduction NVIDIA NeMo LLM service provides a simple and powerful REST API to interact with large language models. This API reference provides information on available endpoints and how to interact with it.  Please **[submit NVBug](https://nvbugswb.nvidia.com/NvBugs5/SWBug.aspx?bugid=3682160&cmtNo=)** (by cloning and submitting) if discovered any issues. Copyright (c) 2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved. Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import nemollm
from nemollm.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customization(self):
        """Test case for create_customization

        Create a customization for a base model trained on a custom dataset.  # noqa: E501
        """
        pass

    def test_delete_customization(self):
        """Test case for delete_customization

        Delete the custom model  # noqa: E501
        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        Delete file  # noqa: E501
        """
        pass

    def test_fetch_model_file_for_customization(self):
        """Test case for fetch_model_file_for_customization

        Fetch NEMO file with trained prompt tokens  # noqa: E501
        """
        pass

    def test_generate_completion(self):
        """Test case for generate_completion

        Create text completion.  # noqa: E501
        """
        pass

    def test_generate_customization_completion(self):
        """Test case for generate_customization_completion

        Create text completion using customization for a model  # noqa: E501
        """
        pass

    def test_get_customization(self):
        """Test case for get_customization

        Get information and status about the custom model  # noqa: E501
        """
        pass

    def test_get_file(self):
        """Test case for get_file

        Get file  # noqa: E501
        """
        pass

    def test_list_customizations_for_model(self):
        """Test case for list_customizations_for_model

        List downstream customizations for the model  # noqa: E501
        """
        pass

    def test_list_files(self):
        """Test case for list_files

        List all files  # noqa: E501
        """
        pass

    def test_list_models(self):
        """Test case for list_models

        List available models  # noqa: E501
        """
        pass

    def test_upload_file(self):
        """Test case for upload_file

        File upload  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    NVIDIA NeMo LLM service

    # Introduction NeMo LLM Service offers state-of-the-art LLMs that were pre-trained on internet-scale text corpora. </br> With NeMo LLM Service API users can invoke the services from within their application code. </br> These models can be flexibly adapted to solve almost any language processing task for your use cases. You can conveniently and quickly try them out, and via an API that you can easily integrate into your applications. </br> Further, the NeMo LLM Service also offers customization capabilities, where the models can be effectively adapted to new tasks, using your own uploaded data.  ### Models:  The NeMo LLM Service is powered by a set of large language models of varying sizes and capabilities. Generally, larger models extend the capabilities of what smaller models can do with text. - Large models, such as the 530B, are excellent for complex tasks that require a deep understanding of human languages and all their nuances, such as text summarization, creative writing, or chatbot applications. - Medium models, such as the 20B, are faster than the large models. They are sufficiently good for many tasks such as writing emails and factual question answering. - Small models, such as the 5B, are the fastest and can perform many simple language tasks, such as text classification and spelling correction. </br></br> Each model can be used for \"Completion\" or text generation with One/Few-Shot Learning as well as \"Customization\" with your custom dataset. </br></br> ### The NeMo LLM Service API  comprises the following features:   - Text Completion. With one of the available and pre-trained model the LLM service responds to an input prompt by generating an extension to the provided intut text, that is, a completion. This technique can be used for solving multiple NLP tasks using Zero/Few-shot learning techniques.   - Model Customization. With which you can finetune an existing model on your own custom data in the form of prompt+completion pairs. This enhances the model’s ability to adapt to your use cases by ingesting hundreds to thousands of domain-specific examples.   Please **[submit NVBug](https://nvbugswb.nvidia.com/NvBugs5/SWBug.aspx?bugid=3682160&cmtNo=)** (by cloning and submitting) if discovered any issues.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


class OpenApiException(Exception):
    """The base exception class for all OpenAPIExceptions"""


class ApiTypeError(OpenApiException, TypeError):
    def __init__(self, msg, path_to_item=None, valid_classes=None, key_type=None):
        """ Raises an exception for TypeErrors

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list): a list of keys an indices to get to the
                                 current_item
                                 None if unset
            valid_classes (tuple): the primitive classes that current item
                                   should be an instance of
                                   None if unset
            key_type (bool): False if our value is a value in a dict
                             True if it is a key in a dict
                             False if our item is an item in a list
                             None if unset
        """
        self.path_to_item = path_to_item
        self.valid_classes = valid_classes
        self.key_type = key_type
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiTypeError, self).__init__(full_msg)


class ApiValueError(OpenApiException, ValueError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list) the path to the exception in the
                received_data dict. None if unset
        """

        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiValueError, self).__init__(full_msg)


class ApiAttributeError(OpenApiException, AttributeError):
    def __init__(self, msg, path_to_item=None):
        """
        Raised when an attribute reference or assignment fails.

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiAttributeError, self).__init__(full_msg)


class ApiKeyError(OpenApiException, KeyError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiKeyError, self).__init__(full_msg)


class ApiException(OpenApiException):
    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "Status Code: {0}\n" "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message


class NotFoundException(ApiException):
    def __init__(self, status=None, reason=None, http_resp=None):
        super(NotFoundException, self).__init__(status, reason, http_resp)


class UnauthorizedException(ApiException):
    def __init__(self, status=None, reason=None, http_resp=None):
        super(UnauthorizedException, self).__init__(status, reason, http_resp)


class ForbiddenException(ApiException):
    def __init__(self, status=None, reason=None, http_resp=None):
        super(ForbiddenException, self).__init__(status, reason, http_resp)


class ServiceException(ApiException):
    def __init__(self, status=None, reason=None, http_resp=None):
        super(ServiceException, self).__init__(status, reason, http_resp)


def render_path(path_to_item):
    """Returns a string representation of a path"""
    result = ""
    for pth in path_to_item:
        if isinstance(pth, int):
            result += "[{0}]".format(pth)
        else:
            result += "['{0}']".format(pth)
    return result



"""
    NVIDIA NeMo LLM service

    # Introduction NVIDIA NeMo LLM service provides a simple and powerful REST API to interact with large language models. This API reference provides information on available endpoints and how to interact with it.  Please **[submit NVBug](https://nvbugswb.nvidia.com/NvBugs5/SWBug.aspx?bugid=3682160&cmtNo=)** (by cloning and submitting) if discovered any issues. Copyright (c) 2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved. Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nemollm
from nemollm.model.model import Model


class TestModel(unittest.TestCase):
    """Model unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testModel(self):
        """Test Model"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Model()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    NVIDIA NeMo LLM service

    # Introduction NeMo LLM Service offers state-of-the-art LLMs that were pre-trained on internet-scale text corpora. </br> With NeMo LLM Service API users can invoke the services from within their application code. </br> These models can be flexibly adapted to solve almost any language processing task for your use cases. You can conveniently and quickly try them out, and via an API that you can easily integrate into your applications. </br> Further, the NeMo LLM Service also offers customization capabilities, where the models can be effectively adapted to new tasks, using your own uploaded data.  ### Models:  The NeMo LLM Service is powered by a set of large language models of varying sizes and capabilities. Generally, larger models extend the capabilities of what smaller models can do with text. - Large models, such as the 530B, are excellent for complex tasks that require a deep understanding of human languages and all their nuances, such as text summarization, creative writing, or chatbot applications. - Medium models, such as the 20B, are faster than the large models. They are sufficiently good for many tasks such as writing emails and factual question answering. - Small models, such as the 5B, are the fastest and can perform many simple language tasks, such as text classification and spelling correction. </br></br> Each model can be used for \"Completion\" or text generation with One/Few-Shot Learning as well as \"Customization\" with your custom dataset. </br></br> ### The NeMo LLM Service API  comprises the following features:   - Text Completion. With one of the available and pre-trained model the LLM service responds to an input prompt by generating an extension to the provided intut text, that is, a completion. This technique can be used for solving multiple NLP tasks using Zero/Few-shot learning techniques.   - Model Customization. With which you can finetune an existing model on your own custom data in the form of prompt+completion pairs. This enhances the model’s ability to adapt to your use cases by ingesting hundreds to thousands of domain-specific examples.   Please **[submit NVBug](https://nvbugswb.nvidia.com/NvBugs5/SWBug.aspx?bugid=3682160&cmtNo=)** (by cloning and submitting) if discovered any issues.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.1.0"

from nemollm.api.default_api import DefaultApi

# import ApiClient
from nemollm.api_client import ApiClient

# import Configuration
from nemollm.configuration import Configuration

# import exceptions
from nemollm.exceptions import (
    ApiAttributeError,
    ApiException,
    ApiKeyError,
    ApiTypeError,
    ApiValueError,
    OpenApiException,
)
from nemollm.handy import Connection
from nemollm.model.completion_request_body import CompletionRequestBody
from nemollm.model.completion_response_body import CompletionResponseBody
from nemollm.model.create_customizations_request_body import CreateCustomizationsRequestBody
from nemollm.model.create_customizations_request_body_additional_hyperparameters import (
    CreateCustomizationsRequestBodyAdditionalHyperparameters,
)
from nemollm.model.customization import Customization
from nemollm.model.customizations_list_response_body import CustomizationsListResponseBody
from nemollm.model.file import File
from nemollm.model.file_format import FileFormat
from nemollm.model.models_list_response import ModelsListResponse
from nemollm.model.p_tuning_hyperparms import PTuningHyperparms
